@@ -253,8 +253,18 @@ class PyHTCC:
         if 'portal/' not in result.url:
             raise RedirectDidNotHappenError(f"{result.url} did not represent the needed redirect")
 
-        self._locationId = result.url.split('portal/')[1].split('/')[0]
-        self._locationId = int(self._locationId)
+        self._set_location_id_from_result(result)
+
+    def _set_location_id_from_result(self, result):
+        '''
+        Attempts to find the location id first from the url then if that fails, in the result's text content
+        '''
+        try:
+            self._locationId = int(result.url.split('portal/')[1].split('/')[0])
+        except ValueError:
+            logger.debug("Unable to grab location id via url... checking content instead")
+            self._locationId = int(re.findall(r'locationId=(\d+)', result.text)[0])
+
         logger.debug(f"location id is {self._locationId}")
 
     def _get_name_for_device_id(self, device_id:int) -> str:
